@@ -1,7 +1,7 @@
 package Huawei::Healthchecker;
 
 #版本信息
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
 use 5.012;
 use warnings;
@@ -77,21 +77,29 @@ sub health_check {
 
     #初始化设备硬件状态巡检结果-数组
     my @hardware_ret;
-    push @hardware_ret, $rev->{"hardware"}{"device_module"}{"health"};
-    push @hardware_ret, $rev->{"hardware"}{"device_power"}{"health"};
-    push @hardware_ret, $rev->{"hardware"}{"device_disk"}{"health"};
-    push @hardware_ret, $rev->{"hardware"}{"device_fan"}{"health"};
-    push @hardware_ret, $rev->{"hardware"}{"device_temperature"}{"health"};
-    push @hardware_ret, $rev->{"hardware"}{"device_alarm"}{"health"};
+    push @hardware_ret,
+        $rev->{"hardware"}{"device_module"}{"health"} || "unknow";
+    push @hardware_ret,
+        $rev->{"hardware"}{"device_power"}{"health"} || "unknow";
+    push @hardware_ret,
+        $rev->{"hardware"}{"device_disk"}{"health"} || "unknow";
+    push @hardware_ret,
+        $rev->{"hardware"}{"device_fan"}{"health"} || "unknow";
+    push @hardware_ret,
+        $rev->{"hardware"}{"device_temperature"}{"health"} || "unknow";
+    push @hardware_ret,
+        $rev->{"hardware"}{"device_alarm"}{"health"} || "unknow";
 
     #初始化设备关键指标巡检结果-数组
     my @status_ret;
-    push @status_ret, $rev->{"status"}{"device_cpu"}{"health"};
-    push @status_ret, $rev->{"status"}{"device_memory"}{"health"};
-    push @status_ret, $rev->{"status"}{"device_ntp"}{"health"};
-    push @status_ret, $rev->{"status"}{"device_vrrp"}{"health"};
-    push @status_ret, $rev->{"status"}{"device_eth_trunk"}{"health"};
-    push @status_ret, $rev->{"status"}{"device_err_down"}{"health"};
+    push @status_ret, $rev->{"status"}{"device_cpu"}{"health"}    || "unknow";
+    push @status_ret, $rev->{"status"}{"device_memory"}{"health"} || "unknow";
+    push @status_ret, $rev->{"status"}{"device_ntp"}{"health"}    || "unknow";
+    push @status_ret, $rev->{"status"}{"device_vrrp"}{"health"}   || "unknow";
+    push @status_ret,
+        $rev->{"status"}{"device_eth_trunk"}{"health"} || "unknow";
+    push @status_ret,
+        $rev->{"status"}{"device_err_down"}{"health"} || "unknow";
 
     #遍历 $rev->{"hardware"} 各属性哈希值
     foreach ( keys %{ $rev->{"hardware"} } ) {
@@ -116,7 +124,7 @@ sub health_check {
     my $score = calculate_score($rev);
 
     #封装计算结果到匿名数组中，方便EXCEL读写
-    my $result = [ \@hardware_ret, \@status_ret, $score, $comment ];
+    my $result = [ @hardware_ret, @status_ret, $score, $comment ];
 
     #返回健康检查结果
     return ( $rev, $result );
@@ -224,44 +232,44 @@ sub calculate_score {
         = ( scalar( keys %{$hardware} ) ) + ( scalar( keys %{$status} ) );
 
     #硬件巡检通过项计数
-    my $hardware_attr;
+    my $hardware_attr = 0;
     foreach ( keys %{$hardware} ) {
         my $ret    = $hardware->{$_};
         my $health = $ret->{"health"};
-        if ( $health eq "pass" ) {
+        if ( defined $health && $health eq "pass" ) {
             ++$hardware_attr;
         }
         else {
             my $alarm = $ret->{"alarm"};
-            if ( $alarm eq "info" ) {
+            if ( defined $alarm && $alarm eq "info" ) {
                 $hardware_attr -= 0.1;
             }
-            elsif ( $alarm eq "alert" ) {
+            elsif ( defined $alarm && $alarm eq "alert" ) {
                 $hardware_attr -= 0.2;
             }
-            elsif ( $alarm eq "critic" ) {
+            elsif ( defined $alarm && $alarm eq "critic" ) {
                 $hardware_attr -= 0.7;
             }
         }
     }
 
     #关键指标巡检通过项计数
-    my $status_attr;
+    my $status_attr = 0;
     foreach ( keys %{$status} ) {
         my $ret    = $status->{$_};
         my $health = $ret->{"health"};
-        if ( $health eq "pass" ) {
+        if ( defined $health && $health eq "pass" ) {
             ++$status_attr;
         }
         else {
             my $alarm = $ret->{"alarm"};
-            if ( $alarm eq "info" ) {
+            if ( defined $alarm && $alarm eq "info" ) {
                 $status_attr -= 0.1;
             }
-            elsif ( $alarm eq "alert" ) {
+            elsif ( defined $alarm && $alarm eq "alert" ) {
                 $status_attr -= 0.2;
             }
-            elsif ( $alarm eq "critic" ) {
+            elsif ( defined $alarm && $alarm eq "critic" ) {
                 $status_attr -= 0.7;
             }
         }
@@ -338,6 +346,7 @@ sub module_status {
     return $result unless $ret;
 
     my @msg;
+
     #遍历巡检结果以捕捉异常模块信息
     foreach ( @{$rev} ) {
         if (/Unregistered/i) {
@@ -350,8 +359,8 @@ sub module_status {
     if (@msg) {
 
         #将异常信息写入日志中
-        $result->{"log"} = "设备板卡告警： \n" . join("\n", @msg);
-        
+        $result->{"log"} = "设备板卡告警：\n" . join( "\n", @msg );
+
         #设置告警等级
         $result->{"alarm"} = "critic";
 
@@ -393,9 +402,11 @@ sub power_status {
     return $result unless $ret;
 
     my @msg;
+
     #遍历巡检结果以捕捉异常模块信息
     foreach ( @{$rev} ) {
         if (/NotSupply/i) {
+
             #将巡检结果命令行写入数组中
             push @msg, $_;
         }
@@ -404,8 +415,8 @@ sub power_status {
     if (@msg) {
 
         #将异常信息写入日志中
-        $result->{"log"} = "设备电源告警： \n" . join("\n", @msg);
-        
+        $result->{"log"} = "设备电源告警：\n" . join( "\n", @msg );
+
         #设置告警等级
         $result->{"alarm"} = "critic";
 
@@ -447,9 +458,11 @@ sub fan_status {
     return $result unless $ret;
 
     my @msg;
+
     #遍历巡检结果以捕捉异常模块信息
     foreach ( @{$rev} ) {
         if (/Abnormal/i) {
+
             #将巡检结果命令行写入数组中
             push @msg, $_;
         }
@@ -458,8 +471,8 @@ sub fan_status {
     if (@msg) {
 
         #将异常信息写入日志中
-        $result->{"log"} = "设备风扇告警： \n" . join("\n", @msg);
-        
+        $result->{"log"} = "设备风扇告警：\n" . join( "\n", @msg );
+
         #设置告警等级
         $result->{"alarm"} = "critic";
 
@@ -501,9 +514,11 @@ sub alarm_status {
     return $result unless $ret;
 
     my @msg;
+
     #遍历巡检结果以捕捉异常模块信息
     foreach ( @{$rev} ) {
         if (/(?<alarm>(critic|alert))/i) {
+
             #将巡检结果命令行写入数组中
             push @msg, $_;
         }
@@ -512,8 +527,8 @@ sub alarm_status {
     if (@msg) {
 
         #将异常信息写入日志中
-        $result->{"log"} = "设备硬件告警： \n" . join("\n", @msg);
-        
+        $result->{"log"} = "设备硬件告警：\n" . join( "\n", @msg );
+
         #设置告警等级
         $result->{"alarm"} = "critic";
 
@@ -555,18 +570,21 @@ sub temperature_status {
     return $result unless $ret;
 
     my @msg;
+
     #遍历巡检结果以捕捉异常模块信息
     foreach ( @{$rev} ) {
         if (/Abnormal/i) {
+
             #将巡检结果命令行写入数组中
             push @msg, $_;
         }
     }
 
     if (@msg) {
+
         #将异常信息写入日志中
-        $result->{"log"} = "设备温度告警： \n" . join("\n", @msg);
-        
+        $result->{"log"} = "设备温度告警：\n" . join( "\n", @msg );
+
         #设置告警等级
         $result->{"alarm"} = "critic";
 
@@ -605,7 +623,7 @@ sub disk_status {
     my $status = 0;
     my $storage;
 
-    #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
+ #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
     foreach ( @{$rev} ) {
 
         #如果命中磁盘关键字将状态指为1
@@ -634,7 +652,7 @@ sub disk_status {
         if (/\s+(\d+)\%\s+/i) {
 
             #写入异常状态
-            $result->{"log"} = "磁盘空间利用率告警：" . "$1\%"
+            $result->{"log"} = "磁盘空间利用率告警：\n" . "$1\%"
                 if ( $1 > $disk_threshold );
             $result->{"alarm"} = "info";
 
@@ -670,7 +688,7 @@ sub cpu_status {
     my $origin = join( "\n", @{$rev} );
     $result->{"origin"} = $origin;
 
-    #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
+ #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
     foreach ( @{$rev} ) {
         if (/CPU Using Percentage/i) {
 
@@ -725,7 +743,7 @@ sub cpu_status {
 
             #写入异常状态
             $result->{"log"}
-                = "CPU历史最大利用率超出阈值： " . "$info[1]"
+                = "CPU历史最大利用率超出阈值：" . "$info[1]"
                 if $max_usage > $cpu_max_threshold;
 
             $result->{"alarm"} = "critic" if $max_usage > $cpu_max_threshold;
@@ -783,7 +801,7 @@ sub memory_status {
 
             #写入异常状态
             $result->{"log"}
-                = "内存利用率超出当前阈值： " . $info[1]
+                = "内存利用率超出当前阈值：" . $info[1]
                 if ( $usage > $memory_threshold );
 
             #设置越线惩罚机制
@@ -843,7 +861,7 @@ sub ntp_status {
             $status =~ s/(^\s+|\s+$)//;
 
             #写入异常状态
-            $result->{"log"} = "NTP时钟源未同步"
+            $result->{"log"} = "NTP时钟源未同步\n"
                 if ( $status eq "unsynchronized" );
             $result->{"alarm"} = "info";
 
@@ -886,7 +904,8 @@ sub vrrp_status {
     return $result if $ret;
 
     my @msg;
-    #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
+
+ #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
     foreach ( @{$rev} ) {
         if (/Initialize/i) {
             push @msg, $_;
@@ -895,8 +914,10 @@ sub vrrp_status {
 
     #写入异常状态信息
     if (@msg) {
+
         #添加异常信息到日志
-        $result->{"log"} = "检测到VRRP工作异常： " . join("\n",@msg);
+        $result->{"log"}
+            = "检测到VRRP工作异常：\n" . join( "\n", @msg );
 
         #设置告警等级
         $result->{"alarm"} = "critic";
@@ -904,7 +925,7 @@ sub vrrp_status {
         #写入后续巡检结果
         $result->{"health"} = "fail";
     }
- 
+
     #返回巡检结果
     return $result;
 }
@@ -939,10 +960,13 @@ sub eth_trunk_status {
     return $result unless $ret;
 
     my @msg;
-    #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
+
+ #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
     foreach ( @{$rev} ) {
+
         #匹配异常状态信息
         if (/Unselect/i) {
+
             #将巡检结果命令行写入数组中
             push @msg, $_;
         }
@@ -951,7 +975,7 @@ sub eth_trunk_status {
     if (@msg) {
 
         #写入异常状态信息
-        $result->{"log"} = "ETH-TRUNK接口异常： " . join("\n",@msg);
+        $result->{"log"} = "ETH-TRUNK接口异常：\n" . join( "\n", @msg );
 
         #设置告警等级
         $result->{"alarm"} = "critic";
@@ -988,29 +1012,33 @@ sub err_down_status {
     $result->{"origin"} = $origin;
 
     #快速检查是否有未注册的模块
-    my $ret = ( grep {/Info: No error-down interface exists/i} @{$rev} ) ? 1 : 0;
+    my $ret
+        = ( grep {/Info: No error-down interface exists/i} @{$rev} ) ? 1 : 0;
 
     #巡检结果命令行输出不存在则跳过
     return $result if $ret;
 
     my @msg;
-    #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
+
+ #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
     foreach ( @{$rev} ) {
-        if (/(efm-threshold-event|efm-remote-failure|bpdu-protection|link-flap|storm-control|mac-address-flapping)/i) {
+        if (/(efm-threshold-event|efm-remote-failure|bpdu-protection|link-flap|storm-control|mac-address-flapping)/i
+            )
+        {
             #将命中行写入数组中
-            push @msg = $_;
+            push @msg, $_;
         }
     }
     if (@msg) {
 
-            #写入异常状态
-            $result->{"log"}= "接口 error-down： " . join("\n", @msg);
+        #写入异常状态
+        $result->{"log"} = "接口 error-down：\n" . join( "\n", @msg );
 
-            #设置告警等级
-            $result->{"alarm"} = "alert";
+        #设置告警等级
+        $result->{"alarm"} = "alert";
 
-            #监控检查状态
-            $result->{"health"} = "fail";
+        #监控检查状态
+        $result->{"health"} = "fail";
     }
 
     #返回巡检结果
